@@ -22,37 +22,39 @@ class mp3(unittest.TestCase):
         self.tmp_dir_obj.cleanup()
 
     def test_chapters(self):
-        md = '[00:10] First\n\n[00:40] Second'
+        md = '[00:00] First\n\n[00:40] Second'
         toc = toc2audio.Toc(md)
         toc2audio.add_tags_mp3(self.tmp_file, toc, add_chapters=True)
         tags = mutagen.id3.ID3(self.tmp_file)
         ctoc = tags['CTOC:toc']
         self.assertEqual(ctoc.child_element_ids, ['chp1', 'chp2'])
         self.assertFalse('TIT2' in ctoc.sub_frames)
-        for i, v in enumerate(((10, 40, 'First'), (40, 86440, 'Second')), 1):
+        length = mutagen.mp3.MP3(self.tmp_file).info.length
+        for i, v in enumerate(((0, 40, 'First'), (40, length, 'Second')), 1):
             start_time, end_time, title = v
             chap = tags[f'CHAP:chp{i}']
-            self.assertEqual(chap.start_time, start_time)
-            self.assertEqual(chap.end_time, end_time)
+            self.assertEqual(chap.start_time, start_time * 1000)
+            self.assertEqual(chap.end_time, end_time * 1000)
             self.assertEqual(chap.sub_frames['TIT2'], title)
 
     def test_previous_chapters(self):
-        md = '[00:10] First\n\n[00:40] Second'
+        md = '[00:00] First\n\n[00:40] Second'
         toc = toc2audio.Toc(md)
         toc2audio.add_tags_mp3(self.tmp_file, toc, add_chapters=True)
 
-        md = '[00:23] Third'
+        md = '[00:00] First\n\n[00:23] Third'
         toc = toc2audio.Toc(md)
         toc2audio.add_tags_mp3(self.tmp_file, toc, add_chapters=True)
 
+        length = mutagen.mp3.MP3(self.tmp_file).info.length
         tags = mutagen.id3.ID3(self.tmp_file)
-        self.assertEqual(tags['CTOC:toc'].child_element_ids, ['chp1'])
+        self.assertEqual(tags['CTOC:toc'].child_element_ids, ['chp1', 'chp2'])
         self.assertFalse('TIT2' in tags['CTOC:toc'].sub_frames)
-        chap = tags['CHAP:chp1']
-        self.assertEqual(chap.start_time, 23)
-        self.assertEqual(chap.end_time, 86400 + 23)
+        chap = tags['CHAP:chp2']
+        self.assertEqual(chap.start_time, 23 * 1000)
+        self.assertEqual(chap.end_time, length * 1000)
         self.assertEqual(chap.sub_frames['TIT2'], 'Third')
-        self.assertFalse('CHAP:chp2' in tags)
+        self.assertFalse('CHAP:chp3' in tags)
 
     def test_toc_title(self):
         audio = mutagen.id3.ID3()
@@ -84,6 +86,15 @@ class mp3(unittest.TestCase):
         tags = mutagen.id3.ID3(self.tmp_file)
         self.assertEqual(tags['CTOC:toc'].sub_frames['TIT2'], 'New title')
 
+    def test_advertisement(self):
+        md = '[00:10] First'
+        toc = toc2audio.Toc(md)
+        toc2audio.add_tags_mp3(self.tmp_file, toc, add_chapters=True)
+        tags = mutagen.id3.ID3(self.tmp_file)
+        version = f'toc2audio {toc2audio.__version__} - '
+        version += 'https://docs.jcea.es/toc2audio/'
+        self.assertIn(version, tags.get('TXXX:tagger'))
+
 
 def test_suite():
     suite = unittest.TestSuite()
