@@ -17,6 +17,14 @@ class timestamps(unittest.TestCase):
             self.assertIsNone(ts[1][1], ts[1])
             self.assertEqual(ts[1][2], 'prueba', ts)
 
+    def test_sub(self):
+        md = '[00:00] Zero\n\n[00:10] First\n\n[00:40] Second'
+        toc = toc2audio.Toc(md)
+        self.assertEqual(toc.timestamps[1][0] - toc2audio.Offset(), 10)
+        self.assertEqual(toc.timestamps[2][0] - toc.timestamps[1][0], 30)
+        with self.assertRaises(TypeError):
+            toc.timestamps[0][0] - 0
+
     def test_offset(self):
         md = '[00:00] First'
         toc = toc2audio.Toc(md)
