@@ -1,10 +1,6 @@
 #!/usr/bin/env python3
 
 import unittest
-import pathlib
-import tempfile
-import shutil
-import re
 
 import mutagen
 import mutagen.oggvorbis
