@@ -2,7 +2,7 @@
 
 """Add Table of Contents and chapters to audio files"""
 
-__version__ = '0.6.0'
+__version__ = '1.0.0'
 
 import argparse
 import pathlib
@@ -52,6 +52,11 @@ class Offset:
         hours = self._hours + offset
         return type(self)(hours, minutes, seconds, compact=compact)
 
+    def __sub__(self, other):
+        if not isinstance(other, type(self)):
+            raise TypeError('Incompatible types')
+        return self.to_seconds() - other.to_seconds()
+
     def __eq__(self, other):
         if not isinstance(other, type(self)):
             raise TypeError('Incompatible types')
@@ -176,6 +181,29 @@ class Toc:
 
         self.timestamps = timestamps
 
+    def print_chapters(self):
+        compact = True
+        if self.timestamps[-1][0].to_seconds() >= 3600:
+            # If the audio length is long, all timestamps should be long
+            compact = False
+        else:
+            # Si algún timestamp no es compacto, mostramos todos
+            # como no compactos.
+            for start_ts, end_ts, title in self.timestamps:
+                if not start_ts.compact:
+                    compact = False
+                    break
+
+        for start_ts, end_ts, title in self.timestamps[:-1]:
+            length = end_ts - start_ts
+            length = f'{length // 60 :2d}m {length % 60 :2d}s'
+            print(f'{start_ts.pprint(compact=compact)} - '
+                  f'{end_ts.pprint(compact=compact)}: ({length}): {title}')
+        alignment = 16 if compact else 19
+        alignment = ' ' * alignment
+        start_ts, _, title = self.timestamps[-1]
+        print(f'{start_ts.pprint(compact=compact)} - {alignment}: {title}')
+
 
 def show_in_browser(toc, msg=None):
     fd, tmpname = tempfile.mkstemp(suffix='.html')
@@ -416,8 +444,7 @@ def main():
     if args.chapters:
         print()
         print('Chapters:')
-        for start_ts, end_ts, title in toc.timestamps:
-            print(f'{start_ts} - {end_ts}: {title}')
+        toc.print_chapters()
 
 
 if __name__ == '__main__':
